alert method
Sends an alert to the event bus for the specified event type.
Implementation
void alert(StoreEvents eventType) {
if (!_eventBus.streamController.isClosed) {
_eventBus.fire(EventInfo(eventType, _nitriteConfig));
}
}
Sends an alert to the event bus for the specified event type.
void alert(StoreEvents eventType) {
if (!_eventBus.streamController.isClosed) {
_eventBus.fire(EventInfo(eventType, _nitriteConfig));
}
}