fromDocument abstract method
Converts a Document to an entity of type T.
Implementation
T fromDocument(Document document, NitriteMapper nitriteMapper);
Converts a Document to an entity of type T.
T fromDocument(Document document, NitriteMapper nitriteMapper);