EntityDecorator<T> class abstract

An interface that can be used to implement a decorator for an entity class of type T, where annotating the class with Entity or its friends is not possible.

Constructors

EntityDecorator()

Properties

entityName String
Gets entity name.
no setter
entityType Type
Gets the entity type of the decorator.
no setter
hashCode int
The hash code for this object.
no setterinherited
idField EntityId?
Gets id field declaration.
no setter
indexFields List<EntityIndex>
Gets index fields declaration.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited