FlattenableFilter class abstract

Represents a filter which can be flattened or consists of multiple constituent filters.

This interface allows filters to be decomposed into multiple sub-filters during query optimization. For example, spatial filters can be split into an index scan filter (for bounding box checks) and a validation filter (for actual geometry checks).

Constructors

FlattenableFilter()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

getFilters() List<Filter>
Returns the list of constituent filters that make up this filter.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited