IndexDescriptor class

A class representing the descriptor of a Nitrite index.

Implemented types

Constructors

IndexDescriptor(String _indexType, Fields _indexFields, String _collectionName)
IndexDescriptor.fromDocument(Document document)
Factory method to create an IndexDescriptor from a Document.
factory

Properties

collectionName String
Gets the collection name.
no setter
fields Fields
Gets the target fields for the index.
no setter
hashCode int
The hash code for this object.
no setterinherited
indexType String
Specifies the type of the index.
no setter
isCompoundIndex bool
Indicates if this descriptor is for a compound index.
no setter
isUniqueIndex bool
Indicates if this descriptor is for a unique index.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

compareTo(IndexDescriptor other) int
Compares this object to another object.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDocument() Document
Converts the IndexDescriptor object to a Document object.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited