LookUp class

Represents lookup parameters in join operation of two collections.

Constructors

LookUp(String localField, String foreignField, String targetField)

Properties

foreignField String
Specifies the field from the foreign records.
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
localField String
Specifies the field from the records input to the join.
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
targetField String
Specifies the new field of the joined records.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited