find abstract method

DocumentCursor find({
  1. Filter? filter,
  2. FindOptions? findOptions,
})

Applies a filter on the collection and returns a customized cursor to the selected documents.

NOTE: If there is an index on the value specified in the filter, this operation will take advantage of the index.

Implementation

DocumentCursor find({Filter? filter, FindOptions? findOptions});