NitriteId class

A unique identifier across the Nitrite database. Each document in a collection is associated with a unique NitriteId.

During insertion if a unique object is supplied in the '_id' field of the document, then the value of the '_id' field will be used to create a new NitriteId. If the '_id' field is not supplied, then nitrite will generate a new NitriteId and will add it to the document.

Implemented types

Properties

hashCode int
The hash code for this object.
no setteroverride
idValue String
Gets the underlying value of the NitriteId.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

compareTo(NitriteId other) int
Compares this object to another object.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
override

Static Methods

createId(String value) NitriteId
Creates a new NitriteId from a value.
newId() NitriteId
Creates a new auto-generated NitriteId.
validId(dynamic value) bool
Validates a value to be used as a NitriteId.