put abstract method

Future<void> put(
  1. Key key,
  2. Value value
)

Associates the specified value with the specified key in this map. If the map previously contained a mapping for the key, the old value is replaced by the specified value.

Implementation

Future<void> put(Key key, Value value);