openRTree<Key extends BoundingBox, Value> abstract method

Future<NitriteRTree<Key, Value>> openRTree<Key extends BoundingBox, Value>(
  1. String rTreeName
)

Opens an NitriteRTree with the given key and value types. The key type must extend the BoundingBox class. Returns a NitriteRTree instance that can be used to perform R-Tree operations on the data.

The R-Tree is automatically created if it does not yet exist. If a R-Tree with this name is already open, this R-Tree is returned.

The Key and Value types are generic and should be specified when calling this method.

Implementation

Future<NitriteRTree<Key, Value>> openRTree<Key extends BoundingBox, Value>(
  String rTreeName,
);