SortableFields class

Represents a collection of fields that can be sorted, with each field having a specified sort order.

Inheritance

Constructors

SortableFields()
SortableFields.from(List<(String, SortOrder)> specs)
factory
SortableFields.withNames(List<String> fields)
Creates a SortableFields instance with field names.
factory

Properties

encodedName String
Gets the encoded name for this Fields.
no setterinherited
fieldNames List<String>
Gets the field names.
no setterinherited
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
sortingOrders List<(String, SortOrder)>
Gets the sort by field specifications.
no setter

Methods

addField(String fieldName) Fields
Adds a field name to a list of field names and returns the updated list.
inherited
addSortedField(String fieldName, SortOrder sortOrder) SortableFields
Adds the sort order for a field.
compareTo(Fields other) int
Compares this object to another object.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
startWith(Fields other) bool
Check if a Fields is a subset of the current Fields;
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited