StoreModule class abstract

Represents a nitrite store module to load as a storage engine for the database.

Inheritance

Constructors

StoreModule()

Properties

hashCode int
The hash code for this object.
no setterinherited
plugins Set<NitritePlugin>
Returns the set of NitritePlugin encapsulated by this module.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

getStore<Config extends StoreConfig>() NitriteStore<Config>
Gets the NitriteStore instance from this module.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited