or function
Returns a filter that performs a logical OR operation on the provided list of filters. The returned filter selects all documents that satisfy at least one of the filters in the list.
Implementation
Filter or(List<Filter> filters) {
filters.notNullOrEmpty('At least two filters must be specified');
if (filters.length < 2) {
throw FilterException('At least two filters must be specified');
}
return OrFilter(filters);
}