AbstractNitriteStore<Config extends StoreConfig> class
abstract
An abstract implementation of the NitriteStore interface that provides common functionality for Nitrite data stores.
- Implemented types
-
- NitriteStore<
Config>
- NitriteStore<
Constructors
- AbstractNitriteStore(Config _storeConfig)
Properties
-
collectionNames
→ Future<
Set< String> > -
Returns a Future that completes with a
Setof all collection names in the Nitrite database.no setteroverride - hashCode → int
-
The hash code for this object.
no setterinherited
-
hasUnsavedChanges
→ Future<
bool> -
Returns a Future that completes with a bool indicating
whether there are unsaved changes in the Nitrite store.
no setterinherited
- isClosed → bool
-
Checks whether this store is closed.
no setterinherited
- isReadOnly → bool
-
Checks whether the store is opened in readonly mode.
no setterinherited
-
keyedRepositoryRegistry
→ Future<
Map< String, Set< >String> > -
Gets the set of all keyed-ObjectRepository details in
the Nitrite database.
no setteroverride
-
repositoryRegistry
→ Future<
Set< String> > -
Returns a Future that completes with a
Setof all repository names in the Nitrite database.no setteroverride - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- storeConfig → Config?
-
Gets the store configuration.
no setteroverride
- storeVersion → String
-
Gets the underlying storage engine version.
no setterinherited
Methods
-
alert(
StoreEvents eventType) → void - Sends an alert to the event bus for the specified event type.
-
beforeClose(
) → Future< void> -
This method is called before closing the store. Any resource cleanup
tasks should be performed in this method.
override
-
close(
) → Future< void> -
Closes the plugin instance.
override
-
closeMap(
String mapName) → Future< void> -
Closes a NitriteMap with the specified name in the store.
inherited
-
closeRTree(
String rTreeName) → Future< void> -
Closes a NitriteRTree with the specified name in the store.
inherited
-
commit(
) → Future< void> -
Commits the changes. For persistent stores, it also writes
changes to disk. It does nothing if there are no unsaved changes.
inherited
-
getCatalog(
) → Future< StoreCatalog> -
Gets the store catalog.
override
-
hasMap(
String mapName) → Future< bool> -
Returns a Future that completes with a boolean value indicating whether
a NitriteMap with the given name exists in the store.
inherited
-
initEventBus(
) → void -
initialize(
NitriteConfig nitriteConfig) → Future< void> -
Initializes the plugin instance.
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
openMap<
Key, Value> (String mapName) → Future< NitriteMap< Key, Value> > -
Opens a NitriteMap with the given
mapNameand returns a Future that completes with the opened map.inherited -
openOrCreate(
) → Future< void> -
Opens the store if it exists, or creates a new one if it doesn't.
inherited
-
openRTree<
Key extends BoundingBox, Value> (String rTreeName) → Future< NitriteRTree< Key, Value> > -
Opens an NitriteRTree with the given key and value types. The key type must
extend the BoundingBox class. Returns a NitriteRTree instance that can
be used to perform R-Tree operations on the data.
inherited
-
removeMap(
String mapName) → Future< void> -
Removes a NitriteMap with the specified name from the store.
inherited
-
removeRTree(
String rTreeName) → Future< void> -
Removes a NitriteRTree with the specified name from the store.
inherited
-
subscribe(
StoreEventListener listener) → void -
Subscribes a StoreEventListener to this store. The listener will be
notified of any changes made to the store.
override
-
toString(
) → String -
A string representation of this object.
inherited
-
unsubscribe(
StoreEventListener listener) → void -
Unsubscribes a StoreEventListener from this store.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited