BoundedRangeFilter class
A range filter constrained by both a lower and an upper bound. Instead of a one-sided index scan plus a post-fetch filter for the other bound, it drives a single bounded index scan from the lower bound to the upper bound.
- Inheritance
-
- Object
- Filter
- NitriteFilter
- FieldBasedFilter
- ComparableFilter
- SortingAwareFilter
- BoundedRangeFilter
Constructors
- BoundedRangeFilter(String field, SortingAwareFilter _lower, SortingAwareFilter _upper)
Properties
- boundInclusive → bool
-
Whether this range bound is inclusive (
>=,<=) rather than exclusive (>,<).no setterinherited - boundType → RangeBoundType
-
For range filters, whether this constrains the lower bound
(
>,>=), the upper bound (<,<=), or neither.no setterinherited - collectionName ↔ String?
-
Gets the name of the collection on which this filter is applied.
getter/setter pairinherited
- comparable → Comparable
-
no setterinherited
- field ↔ String
-
getter/setter pairinherited
- hashCode → int
-
The hash code for this object.
no setterinherited
- isReverseScan ↔ bool
-
Indicates if the filter should scan the index in reverse order.
getter/setter pairinherited
- lowerBound → SortingAwareFilter
-
The original lower-bound filter absorbed into this range.
no setter
- nitriteConfig ↔ NitriteConfig?
-
Gets the NitriteConfig instance.
getter/setter pairinherited
- objectFilter ↔ bool
-
Indicates if this filter is an object filter.
getter/setter pairinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- upperBound → SortingAwareFilter
-
The original upper-bound filter absorbed into this range.
no setter
- value → dynamic
-
Gets the value of the filter.
no setterinherited
Methods
-
and(
Filter filter) → Filter -
Creates an and filter which performs a logical AND operation on
two filters and selects the documents that satisfy both filters.
inherited
-
apply(
Document doc) → bool -
Applies the filter to the given element.
override
-
applyOnIndex(
IndexMap indexMap) → Stream -
Apply this filter on a nitrite index.
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
not(
) → Filter -
Creates a not filter which performs a logical NOT operation on a filter
and selects the documents that do not satisfy the criteria.
inherited
-
or(
Filter filter) → Filter -
Creates an or filter which performs a logical OR operation on
two filters and selects the documents that satisfy at least one
of the filter.
inherited
-
toString(
) → String -
A string representation of this object.
override
-
validateSearchTerm(
NitriteMapper nitriteMapper, String field, dynamic value) → void -
Validates the search term for a given field and value.
inherited
-
yieldValues(
dynamic value) → Stream -
Yield values after index scanning.
inherited
Operators
-
operator &(
Filter other) → Filter -
Creates an and filter which performs a logical AND operation on
two filters and selects the documents that satisfy both filters.
inherited
-
operator ==(
Object other) → bool -
The equality operator.
inherited
-
operator |(
Filter other) → Filter -
Creates an or filter which performs a logical OR operation on
two filters and selects the documents that satisfy at least one
of the filter.
inherited
-
operator ~(
) → Filter -
Creates a not filter which performs a logical NOT operation on a filter
and selects the documents that do not satisfy the criteria.
inherited