DatabaseInstruction class abstract
Represents a migration instruction set for the nitrite database.
- Implemented types
Constructors
- DatabaseInstruction(NitriteMapper _nitriteMapper)
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
addStep(
MigrationStep step) → void -
Adds a migration step to the instruction set.
inherited
-
addUser(
String username, String password) → DatabaseInstruction - Adds an instruction to set an user authentication to the database.
-
changePassword(
String username, String oldPassword, String newPassword) → DatabaseInstruction - Adds an instruction to change the password for the user authentication to the database.
-
customInstruction(
CustomInstruction instruction) → DatabaseInstruction - Adds a custom instruction to perform a user defined operation on the database.
-
dropCollection(
String collectionName) → DatabaseInstruction - Adds an instruction to drop a NitriteCollection from the database.
-
dropRepository<
T> ({EntityDecorator< T> ? entityDecorator, String? entityName, String? key}) → DatabaseInstruction - Adds an instruction to drop a keyed ObjectRepository from the database.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited