EnglishTextTokenizer class
A TextTokenizer implementation for the English languages.
- Inheritance
-
- Object
- BaseTextTokenizer
- EnglishTextTokenizer
Constructors
Properties
Methods
-
convertWord(
String word) → String? -
Converts a
wordinto all lower case and checks if it is a known stop word. If it is, then thewordwill be discarded and will not be considered as a valid token.inherited -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
stopWords(
) → Set< String> -
Gets all stop-words for a language.
override
-
tokenize(
String text) → Set< String> -
Tokenize a
textand discards all stop-words from it.inherited -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited