FindPlan class
A plan for finding documents in a collection.
Constructors
- FindPlan()
Properties
-
blockingSortOrder
↔ List<
(String, SortOrder)> -
Gets the blocking sort order.
getter/setter pair
- byIdFilter ↔ FieldBasedFilter?
-
Gets the FieldBasedFilter for byId search if any.
getter/setter pair
- collectionScanFilter ↔ Filter?
-
Gets the Filter for collection scan if any.
getter/setter pair
- distinct ↔ bool
-
Gets the distinct flag.
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
- indexDescriptor ↔ IndexDescriptor?
-
Gets the IndexDescriptor for index scan if any.
getter/setter pair
- indexScanFilter ↔ IndexScanFilter?
-
Gets the
IndexScanFilterfor index scan if any.getter/setter pair -
indexScanOrder
↔ Map<
String, bool> -
Gets the index scan order.
getter/setter pair
- limit ↔ int?
-
Gets the limit count.
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- skip ↔ int?
-
Gets the skip count.
getter/setter pair
-
subPlans
↔ List<
FindPlan> -
Gets the sub plans.
getter/setter pair
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited