NitriteId class
A unique identifier across the Nitrite database. Each document in a collection is associated with a unique NitriteId.
During insertion if a unique object is supplied in the '_id' field of the document, then the value of the '_id' field will be used to create a new NitriteId. If the '_id' field is not supplied, then nitrite will generate a new NitriteId and will add it to the document.
- Implemented types
Properties
Methods
-
compareTo(
NitriteId other) → int -
Compares this object to another object.
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override