NitriteIndexer class abstract
An abstract class representing a Nitrite indexer plugin.
NitriteIndexer extends NitritePlugin and provides a base class for all Nitrite indexer plugins. It defines the basic structure and functionality of an indexer plugin that can be used to index Nitrite collections.
- Inheritance
-
- Object
- NitritePlugin
- NitriteIndexer
Constructors
Properties
Methods
-
close(
) → Future< void> -
Closes the plugin instance.
inherited
-
dropIndex(
IndexDescriptor indexDescriptor, NitriteConfig nitriteConfig) → Future< void> - Drops the index from the collection.
-
findByFilter(
FindPlan findPlan, NitriteConfig nitriteConfig) → Stream< NitriteId> - Finds the NitriteIds of the documents that match the given filter in the specified collection.
-
initialize(
NitriteConfig nitriteConfig) → Future< void> -
Initializes the plugin instance.
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
removeIndexEntry(
FieldValues fieldValues, IndexDescriptor indexDescriptor, NitriteConfig nitriteConfig) → Future< void> - Removes an index entry for the given field values and index descriptor from the Nitrite database.
-
toString(
) → String -
A string representation of this object.
inherited
-
validateIndex(
Fields fields) → Future< void> - Validates the given fields for indexing.
-
writeIndexEntry(
FieldValues fieldValues, IndexDescriptor indexDescriptor, NitriteConfig nitriteConfig) → Future< void> - Writes an index entry for the given field values and index descriptor.
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited