NitriteMap<Key, Value> class
abstract
Represents a Nitrite key-value pair map. Every piece of data in a Nitrite database is stored in NitriteMap.
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- isClosed → bool
-
Indicates if this NitriteMap is closed.
no setter
- isDropped → bool
-
Indicates if this map is dropped.
no setter
- name → String
-
Gets name of this map.
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
ceilingKey(
Key key) → Future< Key?> - Get the least key that is greater than or equal to this key.
-
clear(
) → Future< void> - Removes all entries in the map.
-
close(
) → Future< void> - Closes this NitriteMap.
-
containsKey(
Key key) → Future< bool> - Determines if the map contains a mapping for the specified key.
-
drop(
) → Future< void> - Deletes the map from the store.
-
entries(
) → Stream< (Key, Value)> - Gets a Stream of the mappings contained in this map.
-
firstKey(
) → Future< Key?> - Get the first key in the map, or null if the map is empty.
-
floorKey(
Key key) → Future< Key?> - Get the largest key that is smaller or equal to this key.
-
getAttributes(
) → Future< Attributes> - Gets the attributes of this map.
-
getStore<
Config extends StoreConfig> () → NitriteStore< Config> - Gets the parent {@link NitriteStore} where this map is stored.
-
higherKey(
Key key) → Future< Key?> - Get the lest key that is greater than the given key, or null if no such key exists.
-
initialize(
) → Future< void> -
inherited
-
isEmpty(
) → Future< bool> - Indicates whether the map is empty.
-
keys(
) → Stream< Key> - Gets a Stream of the keys contained in this map.
-
lastKey(
) → Future< Key?> - Get the last key in the map, or null if the map is empty.
-
lowerKey(
Key key) → Future< Key?> - Get the largest key that is smaller than the given key, or null if no such key exists.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
put(
Key key, Value value) → Future< void> - Associates the specified value with the specified key in this map. If the map previously contained a mapping for the key, the old value is replaced by the specified value.
-
putIfAbsent(
Key key, Value value) → Future< Value?> - Add a key-value pair if it does not yet exist.
-
remove(
Key key) → Future< Value?> - Removes the mapping for a key from this map if it is present.
-
reversedEntries(
) → Stream< (Key, Value)> - Gets a reversed Stream of the mappings contained in this map.
-
setAttributes(
Attributes attributes) → Future< void> - Sets the attributes for this map.
-
size(
) → Future< int> - Get the number of entries, as an integer. 0x7fffffffffffffff is returned if there are more than these entries.
-
toString(
) → String -
A string representation of this object.
inherited
-
updateLastModifiedTime(
) → Future< void> - Update last modified time of the map.
-
values(
) → Stream< Value> - Gets a Stream of the values contained in this map.
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
-
operator [](
Key key) → Future< Value?> -
Gets the value mapped with the specified key or
nullotherwise.