find abstract method
Applies a filter on the repository and returns a customized cursor to the selected objects.
NOTE: If there is an index on the value specified in the filter, this operation will take advantage of the index.
Implementation
Cursor<T> find({Filter? filter, FindOptions? findOptions});