RepositoryInstruction class abstract
Represents a migration instruction set for ObjectRepository.
- Implemented types
Constructors
Properties
- entityName → String
-
The entity name of the ObjectRepository.
no setter
- hashCode → int
-
The hash code for this object.
no setterinherited
- key → String?
-
The key of the ObjectRepository.
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
addField(
String fieldName, {dynamic defaultValue, Generator? generator}) → RepositoryInstruction - Adds an instruction to add new field with either a default value or a value generator, into the entity in the ObjectRepository.
-
addStep(
MigrationStep step) → void -
Adds a migration step to the instruction set.
inherited
-
changeDataType(
String fieldName, TypeConverter converter) → RepositoryInstruction - Adds an instruction to change the datatype of a field of the entity in the ObjectRepository.
-
changeIdField(
Fields oldField, Fields newField) → RepositoryInstruction - Adds an instruction to change the id field of an entity in the ObjectRepository.
-
createIndex(
String indexType, List< String> fieldNames) → RepositoryInstruction - Adds an instruction to create an index in the ObjectRepository.
-
deleteField(
String fieldName) → RepositoryInstruction - Adds an instruction to delete a field from the entity in the ObjectRepository.
-
dropAllIndices(
) → RepositoryInstruction - Adds an instruction to drop all indices from the ObjectRepository.
-
dropIndex(
List< String> fieldNames) → RepositoryInstruction - Adds an instruction to drop an index from the ObjectRepository.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
renameField(
String oldName, String newName) → RepositoryInstruction - Adds an instruction to rename a field to the entity in the ObjectRepository.
-
renameRepository(
String entityName, {String? key}) → RepositoryInstruction - Adds an instruction to rename the ObjectRepository.
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited